@@ -113,9 +113,12 @@ class EmergeCommand(CommandExecutor):
     emerge_cmd = getProgPath("/usr/bin/emerge")
 
     def __init__(self, packages, extra_params=None, env=None, cwd=None,
-                 logfile=None, emerge_default_opts=None, use=""):
+                 logfile=None, emerge_default_opts=None, env_update=None,
+                 use=""):
         extra_params = extra_params or []
         if env is None:
+            env = {}
+            env.update(os.environ)
             if emerge_default_opts is None:
                 env = {'CLEAN_DELAY': '0'}
             else:
@@ -127,7 +130,8 @@ class EmergeCommand(CommandExecutor):
                 }
                 if use:
                     env["USE"] = use
-            env.update(os.environ)
+        if env_update is not None:
+            env.update(env_update)
 
         params = self.default_params + extra_params + packages
         super(EmergeCommand, self).__init__(self.emerge_cmd, params=params,
